summaryrefslogtreecommitdiff
path: root/common
diff options
context:
space:
mode:
authorbee <beebeeb5k@gmail.com>2026-05-01 23:45:21 +0530
committerbee <beebeeb5k@gmail.com>2026-05-01 23:45:21 +0530
commitcd08309515bce3796777f4b20efffd379b9fabcc (patch)
tree9bc843dc067983511b31139b5c71afdd12a8e20e /common
parent1bb49481dbec223e68df4f60fa1d425525e16cff (diff)
Homecoming
Diffstat (limited to 'common')
-rw-r--r--common/modules/default.nix6
-rw-r--r--common/modules/emacs/default.nix33
-rw-r--r--common/modules/emacs/doom/config.el75
-rw-r--r--common/modules/emacs/doom/init.el199
-rw-r--r--common/modules/emacs/doom/packages.el54
-rw-r--r--common/modules/matugen/default.nix10
-rw-r--r--common/modules/matugen/templates/matugen-mango.nix2
-rw-r--r--common/modules/matugen/templates/matugen-neovim.nix28
-rw-r--r--common/modules/matugen/templates/matugen-xresources.nix2
-rw-r--r--common/modules/terminal/default.nix6
-rw-r--r--common/modules/window_managers/default.nix72
-rw-r--r--common/modules/window_managers/dwm/default.nix (renamed from common/modules/dwm/default.nix)47
-rw-r--r--common/modules/window_managers/dwm/picom.nix (renamed from common/modules/dwm/picom.nix)2
-rw-r--r--common/modules/window_managers/dwm/scripts.nix (renamed from common/modules/dwm/scripts.nix)0
-rw-r--r--common/modules/window_managers/hyprland/default.nix (renamed from common/modules/hyprland/default.nix)119
-rw-r--r--common/modules/window_managers/mango/default.nix (renamed from common/modules/mango/default.nix)63
-rw-r--r--common/programs/vesktop.nix29
17 files changed, 500 insertions, 247 deletions
diff --git a/common/modules/default.nix b/common/modules/default.nix
index ade06b3..0925ffd 100644
--- a/common/modules/default.nix
+++ b/common/modules/default.nix
@@ -9,12 +9,10 @@ let
inherit inputs homeManager;
};
modules = {
- mango = import ./mango args;
- hypr = import ./hyprland args;
- dwm = import ./dwm args;
+ windowManagers = import ./window_managers args;
terminal = import ./terminal args;
- beevim = import ./beevim args;
matugen = import ./matugen args;
+ emacs = import ./emacs args;
};
in
modules
diff --git a/common/modules/emacs/default.nix b/common/modules/emacs/default.nix
new file mode 100644
index 0000000..4566f57
--- /dev/null
+++ b/common/modules/emacs/default.nix
@@ -0,0 +1,33 @@
+{
+ homeManager,
+ inputs,
+ moduleNameSpace,
+ ...
+}:
+{
+ pkgs,
+ config,
+ lib,
+ ...
+}:
+let
+ cfg = config.${moduleNameSpace}.emacs;
+in
+{
+ imports = lib.optionals homeManager [
+ inputs.nix-doom-emacs-unstraightened.homeModule
+ ];
+
+ options.${moduleNameSpace}.emacs = {
+ enable = lib.mkEnableOption "Enable emacs";
+ };
+
+ config = lib.mkIf cfg.enable (
+ lib.optionalAttrs homeManager {
+ programs.doom-emacs = {
+ enable = true;
+ doomDir = ./doom; # or e.g. `./doom.d` for a local configuration
+ };
+ }
+ );
+}
diff --git a/common/modules/emacs/doom/config.el b/common/modules/emacs/doom/config.el
new file mode 100644
index 0000000..5308e62
--- /dev/null
+++ b/common/modules/emacs/doom/config.el
@@ -0,0 +1,75 @@
+;;; $DOOMDIR/config.el -*- lexical-binding: t; -*-
+
+;; Place your private configuration here! Remember, you do not need to run 'doom
+;; sync' after modifying this file!
+
+
+;; Some functionality uses this to identify you, e.g. GPG configuration, email
+;; clients, file templates and snippets. It is optional.
+;; (setq user-full-name "John Doe"
+;; user-mail-address "john@doe.com")
+
+;; Doom exposes five (optional) variables for controlling fonts in Doom:
+;;
+;; - `doom-font' -- the primary font to use
+;; - `doom-variable-pitch-font' -- a non-monospace font (where applicable)
+;; - `doom-big-font' -- used for `doom-big-font-mode'; use this for
+;; presentations or streaming.
+;; - `doom-symbol-font' -- for symbols
+;; - `doom-serif-font' -- for the `fixed-pitch-serif' face
+;;
+;; See 'C-h v doom-font' for documentation and more examples of what they
+;; accept. For example:
+;;
+(setq doom-font (font-spec :family "IosevkaInput" :size 14 :weight 'semi-light)
+ doom-variable-pitch-font (font-spec :family "IosevkaInput" :size 15))
+;;
+;; If you or Emacs can't find your font, use 'M-x describe-font' to look them
+;; up, `M-x eval-region' to execute elisp code, and 'M-x doom/reload-font' to
+;; refresh your font settings. If Emacs still can't find your font, it likely
+;; wasn't installed correctly. Font issues are rarely Doom issues!
+
+;; There are two ways to load a theme. Both assume the theme is installed and
+;; available. You can either set `doom-theme' or manually load a theme with the
+;; `load-theme' function. This is the default:
+(setq doom-theme 'doom-one)
+
+;; This determines the style of line numbers in effect. If set to `nil', line
+;; numbers are disabled. For relative line numbers, set this to `relative'.
+(setq display-line-numbers-type t)
+
+;; If you use `org' and don't want your org files in the default location below,
+;; change `org-directory'. It must be set before org loads!
+(setq org-directory "~/org/")
+
+
+;; Whenever you reconfigure a package, make sure to wrap your config in an
+;; `with-eval-after-load' block, otherwise Doom's defaults may override your
+;; settings. E.g.
+;;
+;; (with-eval-after-load 'PACKAGE
+;; (setq x y))
+;;
+;; The exceptions to this rule:
+;;
+;; - Setting file/directory variables (like `org-directory')
+;; - Setting variables which explicitly tell you to set them before their
+;; package is loaded (see 'C-h v VARIABLE' to look them up).
+;; - Setting doom variables (which start with 'doom-' or '+').
+;;
+;; Here are some additional functions/macros that will help you configure Doom.
+;;
+;; - `load!' for loading external *.el files relative to this one
+;; - `add-load-path!' for adding directories to the `load-path', relative to
+;; this file. Emacs searches the `load-path' when you load packages with
+;; `require' or `use-package'.
+;; - `map!' for binding new keys
+;;
+;; To get information about any of these functions/macros, move the cursor over
+;; the highlighted symbol at press 'K' (non-evil users must press 'C-c c k').
+;; This will open documentation for it, including demos of how they are used.
+;; Alternatively, use `C-h o' to look up a symbol (functions, variables, faces,
+;; etc).
+;;
+;; You can also try 'gd' (or 'C-c c d') to jump to their definition and see how
+;; they are implemented.
diff --git a/common/modules/emacs/doom/init.el b/common/modules/emacs/doom/init.el
new file mode 100644
index 0000000..34d9172
--- /dev/null
+++ b/common/modules/emacs/doom/init.el
@@ -0,0 +1,199 @@
+;;; init.el -*- lexical-binding: t; -*-
+
+;; This file controls what Doom modules are enabled and what order they load
+;; in. Remember to run 'doom sync' after modifying it!
+
+;; NOTE: Press 'SPC h d h' (or 'C-h d h' for non-vim users) to access Doom's
+;; documentation. There you'll find a link to Doom's Module Index where all of
+;; our modules are listed, including what flags they support.
+
+;; NOTE: Move your cursor over a module's name (or its flags) and press 'K' (or
+;; 'C-c c k' for non-vim users) to view its documentation. This works on flags
+;; as well (those symbols that start with a plus).
+;;
+;; Alternatively, press 'gd' (or 'C-c c d') on a module to browse its
+;; directory (for easy access to its source code).
+
+(doom! :input
+ ;;bidi ; (tfel ot) thgir etirw uoy gnipleh
+ ;;chinese
+ ;;japanese
+ ;;layout ; auie,ctsrnm is the superior home row
+
+ :completion
+ ;;company ; the ultimate code completion backend
+ (corfu +orderless) ; complete with cap(f), cape and a flying feather!
+ ;;helm ; the *other* search engine for love and life
+ ;;ido ; the other *other* search engine...
+ ;;ivy ; a search engine for love and life
+ vertico ; the search engine of the future
+
+ :ui
+ ;;deft ; notational velocity for Emacs
+ doom ; what makes DOOM look the way it does
+ dashboard ; a nifty splash screen for Emacs
+ ;;doom-quit ; DOOM quit-message prompts when you quit Emacs
+ ;;(emoji +unicode) ; 🙂
+ hl-todo ; highlight TODO/FIXME/NOTE/DEPRECATED/HACK/REVIEW
+ ;;indent-guides ; highlighted indent columns
+ ;;ligatures ; ligatures and symbols to make your code pretty again
+ ;;minimap ; show a map of the code on the side
+ modeline ; snazzy, Atom-inspired modeline, plus API
+ ;;nav-flash ; blink cursor line after big motions
+ ;;neotree ; a project drawer, like NERDTree for vim
+ ophints ; highlight the region an operation acts on
+ (popup +defaults) ; tame sudden yet inevitable temporary windows
+ ;;smooth-scroll ; So smooth you won't believe it's not butter
+ ;;tabs ; a tab bar for Emacs
+ ;;treemacs ; a project drawer, like neotree but cooler
+ ;;unicode ; extended unicode support for various languages
+ (vc-gutter +pretty) ; vcs diff in the fringe
+ vi-tilde-fringe ; fringe tildes to mark beyond EOB
+ ;;window-select ; visually switch windows
+ workspaces ; tab emulation, persistence & separate workspaces
+ ;;zen ; distraction-free coding or writing
+
+ :editor
+ (evil +everywhere); come to the dark side, we have cookies
+ file-templates ; auto-snippets for empty files
+ fold ; (nigh) universal code folding
+ ;;(format +onsave) ; automated prettiness
+ ;;god ; run Emacs commands without modifier keys
+ ;;lispy ; vim for lisp, for people who don't like vim
+ ;;multiple-cursors ; editing in many places at once
+ ;;objed ; text object editing for the innocent
+ ;;parinfer ; turn lisp into python, sort of
+ ;;rotate-text ; cycle region at point between text candidates
+ snippets ; my elves. They type so I don't have to
+ (whitespace +guess +trim) ; a butler for your whitespace
+ ;;word-wrap ; soft wrapping with language-aware indent
+
+ :emacs
+ dired ; making dired pretty [functional]
+ electric ; smarter, keyword-based electric-indent
+ ;;eww ; the internet is gross
+ ;;ibuffer ; interactive buffer management
+ tramp ; remote files at your arthritic fingertips
+ undo ; persistent, smarter undo for your inevitable mistakes
+ vc ; version-control and Emacs, sitting in a tree
+
+ :term
+ ;;eshell ; the elisp shell that works everywhere
+ ;;shell ; simple shell REPL for Emacs
+ ;;term ; basic terminal emulator for Emacs
+ ;;vterm ; the best terminal emulation in Emacs
+
+ :checkers
+ syntax ; tasing you for every semicolon you forget
+ ;;(spell +flyspell) ; tasing you for misspelling mispelling
+ ;;grammar ; tasing grammar mistake every you make
+
+ :tools
+ ;;ansible
+ ;;biblio ; Writes a PhD for you (citation needed)
+ ;;collab ; buffers with friends
+ ;;debugger ; stepping through code, to help you add bugs
+ ;;direnv
+ ;;docker
+ ;;editorconfig ; let someone else argue about tabs vs spaces
+ ;;ein ; tame Jupyter notebooks with emacs
+ (eval +overlay) ; run code, run (also, repls)
+ lookup ; navigate your code and its documentation
+ ;;llm ; when I said you needed friends, I didn't mean...
+ (lsp +eglot) ; M-x vscode
+ magit ; a git porcelain for Emacs
+ ;;make ; run make tasks from Emacs
+ ;;pass ; password manager for nerds
+ ;;pdf ; pdf enhancements
+ ;;terraform ; infrastructure as code
+ ;;tmux ; an API for interacting with tmux
+ tree-sitter ; syntax and parsing, sitting in a tree...
+ ;;upload ; map local to remote projects via ssh/ftp
+
+ :os
+ (:if (featurep :system 'macos) macos) ; improve compatibility with macOS
+ ;;tty ; improve the terminal Emacs experience
+
+ :lang
+ ;;ada ; In strong typing we (blindly) trust
+ ;;(agda +local) ; types of types of types of types...
+ ;;beancount ; mind the GAAP
+ (cc +lsp) ; C > C++ == 1
+ ;;clojure ; java with a lisp
+ ;;common-lisp ; if you've seen one lisp, you've seen them all
+ ;;coq ; proofs-as-programs
+ ;;crystal ; ruby at the speed of c
+ ;;csharp ; unity, .NET, and mono shenanigans
+ ;;data ; config/data formats
+ ;;(dart +flutter) ; paint ui and not much else
+ ;;dhall
+ ;;elixir ; erlang done right
+ ;;elm ; care for a cup of TEA?
+ emacs-lisp ; drown in parentheses
+ ;;erlang ; an elegant language for a more civilized age
+ ;;ess ; emacs speaks statistics
+ ;;factor
+ ;;faust ; dsp, but you get to keep your soul
+ ;;fortran ; in FORTRAN, GOD is REAL (unless declared INTEGER)
+ ;;fsharp ; ML stands for Microsoft's Language
+ ;;fstar ; (dependent) types and (monadic) effects and Z3
+ ;;gdscript ; the language you waited for
+ ;;(go +lsp) ; the hipster dialect
+ ;;(graphql +lsp) ; Give queries a REST
+ ;;(haskell +lsp) ; a language that's lazier than I am
+ ;;hy ; readability of scheme w/ speed of python
+ ;;idris ; a language you can depend on
+ ;;json ; At least it ain't XML
+ ;;janet ; Fun fact: Janet is me!
+ ;;(java +lsp) ; the poster child for carpal tunnel syndrome
+ ;;javascript ; all(hope(abandon(ye(who(enter(here))))))
+ ;;julia ; a better, faster MATLAB
+ ;;kotlin ; a better, slicker Java(Script)
+ ;;latex ; writing papers in Emacs has never been so fun
+ ;;lean ; for folks with too much to prove
+ ;;ledger ; be audit you can be
+ ;;lua ; one-based indices? one-based indices
+ markdown ; writing docs for people to ignore
+ ;;nim ; python + lisp at the speed of c
+ nix ; I hereby declare "nix geht mehr!"
+ ;;ocaml ; an objective camel
+ ;;odin ; C, minus its footguns
+ org ; organize your plain life in plain text
+ ;;php ; perl's insecure younger brother
+ ;;plantuml ; diagrams for confusing people more
+ ;;graphviz ; diagrams for confusing yourself even more
+ ;;purescript ; javascript, but functional
+ ;;python ; beautiful is better than ugly
+ ;;qt ; the 'cutest' gui framework ever
+ ;;racket ; a DSL for DSLs
+ ;;raku ; the artist formerly known as perl6
+ ;;rest ; Emacs as a REST client
+ ;;rst ; ReST in peace
+ ;;(ruby +rails) ; 1.step {|i| p "Ruby is #{i.even? ? 'love' : 'life'}"}
+ (rust +lsp) ; Fe2O3.unwrap().unwrap().unwrap().unwrap()
+ ;;scala ; java, but good
+ ;;(scheme +guile) ; a fully conniving family of lisps
+ sh ; she sells {ba,z,fi}sh shells on the C xor
+ ;;sml
+ ;;solidity ; do you need a blockchain? No.
+ ;;swift ; who asked for emoji variables?
+ ;;terra ; Earth and Moon in alignment for performance.
+ ;;web ; the tubes
+ ;;yaml ; JSON, but readable
+ zig ; C, but simpler
+
+ :email
+ ;;(mu4e +org +gmail)
+ ;;notmuch
+ ;;(wanderlust +gmail)
+
+ :app
+ ;;calendar
+ ;;emms
+ ;;everywhere ; *leave* Emacs!? You must be joking
+ ;;irc ; how neckbeards socialize
+ ;;(rss +org) ; emacs as an RSS reader
+
+ :config
+ ;;literate
+ (default +bindings +smartparens))
diff --git a/common/modules/emacs/doom/packages.el b/common/modules/emacs/doom/packages.el
new file mode 100644
index 0000000..d2680fe
--- /dev/null
+++ b/common/modules/emacs/doom/packages.el
@@ -0,0 +1,54 @@
+;; -*- no-byte-compile: t; -*-
+;;; $DOOMDIR/packages.el
+
+;; To install a package:
+;;
+;; 1. Declare them here in a `package!' statement,
+;; 2. Run 'doom sync' in the shell,
+;; 3. Restart Emacs.
+;;
+;; Use 'C-h f package\!' to look up documentation for the `package!' macro.
+
+
+;; To install SOME-PACKAGE from MELPA, ELPA or emacsmirror:
+;; (package! some-package)
+
+;; To install a package directly from a remote git repo, you must specify a
+;; `:recipe'. You'll find documentation on what `:recipe' accepts here:
+;; https://github.com/radian-software/straight.el#the-recipe-format
+;; (package! another-package
+;; :recipe (:host github :repo "username/repo"))
+
+;; If the package you are trying to install does not contain a PACKAGENAME.el
+;; file, or is located in a subdirectory of the repo, you'll need to specify
+;; `:files' in the `:recipe':
+;; (package! this-package
+;; :recipe (:host github :repo "username/repo"
+;; :files ("some-file.el" "src/lisp/*.el")))
+
+;; If you'd like to disable a package included with Doom, you can do so here
+;; with the `:disable' property:
+;; (package! builtin-package :disable t)
+
+;; You can override the recipe of a built in package without having to specify
+;; all the properties for `:recipe'. These will inherit the rest of its recipe
+;; from Doom or MELPA/ELPA/Emacsmirror:
+;; (package! builtin-package :recipe (:nonrecursive t))
+;; (package! builtin-package-2 :recipe (:repo "myfork/package"))
+
+;; Specify a `:branch' to install a package from a particular branch or tag.
+;; This is required for some packages whose default branch isn't 'master' (which
+;; our package manager can't deal with; see radian-software/straight.el#279)
+;; (package! builtin-package :recipe (:branch "develop"))
+
+;; Use `:pin' to specify a particular commit to install.
+;; (package! builtin-package :pin "1a2b3c4d5e")
+
+
+;; Doom's packages are pinned to a specific commit and updated from release to
+;; release. The `unpin!' macro allows you to unpin single packages...
+;; (unpin! pinned-package)
+;; ...or multiple packages
+;; (unpin! pinned-package another-pinned-package)
+;; ...Or *all* packages (NOT RECOMMENDED; will likely break things)
+;; (unpin! t)
diff --git a/common/modules/matugen/default.nix b/common/modules/matugen/default.nix
index 6bf73a2..ecc9255 100644
--- a/common/modules/matugen/default.nix
+++ b/common/modules/matugen/default.nix
@@ -48,7 +48,7 @@ in
output_path = '~/.config/zathura/matugen'
''}
- ${lib.optionalString config.beeMods.mango.enable ''
+ ${lib.optionalString config.beeMods.windowManagers.mango.enable ''
[templates.mango]
input_path = '~/.config/matugen/templates/mango.conf'
output_path = '~/.config/mango/mango-colors.conf'
@@ -67,7 +67,7 @@ in
output_path = '~/.config/yazi/theme.toml'
''}
- ${lib.optionalString (config.beeMods.dwm.enable) ''
+ ${lib.optionalString (config.beeMods.windowManagers.dwm.enable) ''
[templates.Xresources]
input_path = "~/.config/matugen/templates/colors-xresources"
output_path = "~/.config/x11/matugen.Xresources"
@@ -86,12 +86,6 @@ in
post_hook = "dunstctl reload"
''}
- ${lib.optionalString config.beeMods.beeVim.enable ''
- [templates.neovim]
- input_path = "~/.config/matugen/templates/neovim.json"
- output_path = "~/.config/matugen/neovim_matugen.json"
- ''}
-
${lib.optionalString
(config.beeMods.terminal.default == "foot" || config.beeMods.terminal.default == "ghostty")
''
diff --git a/common/modules/matugen/templates/matugen-mango.nix b/common/modules/matugen/templates/matugen-mango.nix
index b6a89b2..385e212 100644
--- a/common/modules/matugen/templates/matugen-mango.nix
+++ b/common/modules/matugen/templates/matugen-mango.nix
@@ -4,7 +4,7 @@
...
}:
{
- config = lib.mkIf config.beeMods.mango.enable {
+ config = lib.mkIf config.beeMods.windowManagers.mango.enable {
xdg.configFile = {
"matugen/templates/mango.conf" = {
text = ''
diff --git a/common/modules/matugen/templates/matugen-neovim.nix b/common/modules/matugen/templates/matugen-neovim.nix
deleted file mode 100644
index dcb84a2..0000000
--- a/common/modules/matugen/templates/matugen-neovim.nix
+++ /dev/null
@@ -1,28 +0,0 @@
-{
- config,
- lib,
- ...
-}:
-{
- config = lib.mkIf config.beeMods.beeVim.enable {
- xdg.configFile = {
- "matugen/templates/neovim.json" = {
- text =
- # json
- ''
- {
- "source_color": "{{colors.primary.default.hex}}",
- <* if {{ is_dark_mode }} *>
- "background": "{{colors.background.default.hex}}",
- <* else *>
- "background": "{{colors.surface_container.default.hex}}",
- <* endif *>
- "harmony": 0.5,
- "mode": "{{mode}}"
- }
- '';
-
- };
- };
- };
-}
diff --git a/common/modules/matugen/templates/matugen-xresources.nix b/common/modules/matugen/templates/matugen-xresources.nix
index f33fda2..292f0f2 100644
--- a/common/modules/matugen/templates/matugen-xresources.nix
+++ b/common/modules/matugen/templates/matugen-xresources.nix
@@ -4,7 +4,7 @@
...
}:
{
- config = lib.mkIf config.beeMods.mango.enable {
+ config = lib.mkIf config.beeMods.windowManagers.dwm.enable {
xdg.configFile."matugen/templates/colors-xresources" = {
text = ''
dwm.normbordercolor : {{colors.outline.default.hex}}
diff --git a/common/modules/terminal/default.nix b/common/modules/terminal/default.nix
index 3bc4a56..b777faf 100644
--- a/common/modules/terminal/default.nix
+++ b/common/modules/terminal/default.nix
@@ -39,7 +39,7 @@ with lib;
};
size = mkOption {
type = types.float;
- default = 13.0;
+ default = 11.0;
};
bright_color_is_bold = mkEnableOption "bright colors in bold font";
@@ -50,13 +50,13 @@ with lib;
window = {
padding-x = mkOption {
type = types.int;
- default = 10;
+ default = 3;
description = "Window padding x axis (pixels).";
};
padding-y = mkOption {
type = types.int;
- default = 10;
+ default = 3;
description = "Window padding y axis (pixels).";
};
};
diff --git a/common/modules/window_managers/default.nix b/common/modules/window_managers/default.nix
new file mode 100644
index 0000000..7b51946
--- /dev/null
+++ b/common/modules/window_managers/default.nix
@@ -0,0 +1,72 @@
+{
+ homeManager,
+ inputs,
+ moduleNameSpace,
+ ...
+}:
+{
+ config,
+ lib,
+ pkgs,
+ ...
+}:
+let
+ args = {
+ moduleNameSpace = "beeMods";
+ inherit inputs homeManager;
+ };
+in
+{
+ imports = [
+ (import ./mango args)
+ (import ./hyprland args)
+ (import ./dwm args)
+ ];
+
+ options.${moduleNameSpace}.windowManagers = {
+ mango.enable = lib.mkEnableOption "Enable mangowm";
+ dwm.enable = lib.mkEnableOption "Enable dwm";
+ hyprland.enable = lib.mkEnableOption "Enable hyprland";
+ eyeCandy = {
+ animations.enable = lib.mkEnableOption "Uiiiiiiiiiii";
+ window = {
+ blur = {
+ enable = lib.mkEnableOption "Enable window blur";
+ passes = lib.mkOption {
+ type = lib.types.int;
+ default = 1;
+ };
+ radius = lib.mkOption {
+ type = lib.types.int;
+ default = 10;
+ };
+ };
+ shadows.enable = lib.mkEnableOption "Enable window drop shadows";
+ borderRadius = lib.mkOption {
+ type = lib.types.int;
+ default = 0;
+ description = "Border radius";
+ };
+ opacity = lib.mkOption {
+ type = lib.types.number;
+ default = 1.0;
+ description = "Window opacity";
+ };
+ };
+ };
+ };
+ config = (
+ if homeManager then
+ {
+ home.packages = with pkgs; [
+ wl-clipboard
+ cliphist
+ brightnessctl
+ ];
+ }
+ else
+ {
+ }
+ );
+
+}
diff --git a/common/modules/dwm/default.nix b/common/modules/window_managers/dwm/default.nix
index 07ddef6..f665d06 100644
--- a/common/modules/dwm/default.nix
+++ b/common/modules/window_managers/dwm/default.nix
@@ -11,7 +11,7 @@
...
}:
let
- cfg = config.${moduleNameSpace}.dwm;
+ cfg = config.${moduleNameSpace}.windowManagers;
snipx11 = pkgs.writeShellScript "snipx11" ''
case $1 in
full)
@@ -97,43 +97,11 @@ let
in
{
imports = [
- (import ./picom.nix homeManager)
+ # (import ./picom.nix homeManager)
(import ./scripts.nix homeManager)
];
- options.${moduleNameSpace}.dwm = {
- enable = lib.mkEnableOption "dwm setup";
- picom = {
- enable = lib.mkEnableOption "enable picom compositor";
- animations = lib.mkEnableOption "enable animations";
- shadow = lib.mkEnableOption "enable shadows";
- window = {
- opacity = {
- active = lib.mkOption {
- type = lib.types.float;
- default = 1.0;
- };
- inactive = lib.mkOption {
- type = lib.types.float;
- default = 1.0;
- };
- };
- blur = {
- enable = lib.mkEnableOption "Enable window blur";
- strength = lib.mkOption {
- type = lib.types.int;
- default = 1;
- };
- size = lib.mkOption {
- type = lib.types.int;
- default = 10;
- };
- };
- };
- };
- };
-
- config = lib.mkIf cfg.enable (
+ config = lib.mkIf cfg.dwm.enable (
if !homeManager then
{
services.xserver = {
@@ -169,13 +137,6 @@ in
clipcatd &
slstatus &
sync_dms
- ${lib.optionalString (!cfg.picom.enable) ''
- xrandr --output eDP --set TearFree on
- ''}
- ${lib.optionalString (cfg.picom.enable) ''
- systemctl --user restart picom.service
- ''}
-
systemctl --user restart xidlehook.service xautolock-session.service xss-lock.service clipcat.service
'';
};
@@ -238,7 +199,7 @@ in
"${config.beeMods.terminal.font.family}:size=${toString config.beeMods.terminal.font.size}:antialias=true:autohint=true";
"dmenu.font" =
"${config.beeMods.terminal.font.family}:size=${toString config.beeMods.terminal.font.size}";
- "st.borderpx" = 5;
+ "st.borderpx" = 2;
};
}
);
diff --git a/common/modules/dwm/picom.nix b/common/modules/window_managers/dwm/picom.nix
index 93d4b9b..f0b8d17 100644
--- a/common/modules/dwm/picom.nix
+++ b/common/modules/window_managers/dwm/picom.nix
@@ -1,7 +1,7 @@
homeManager:
{ config, lib, ... }:
let
- cfg = config.beeMods.dwm.picom;
+ cfg = config.beeMods.windowManagers;
in
{
config = lib.mkIf cfg.enable (
diff --git a/common/modules/dwm/scripts.nix b/common/modules/window_managers/dwm/scripts.nix
index 5b52686..5b52686 100644
--- a/common/modules/dwm/scripts.nix
+++ b/common/modules/window_managers/dwm/scripts.nix
diff --git a/common/modules/mango/default.nix b/common/modules/window_managers/mango/default.nix
index 7938c05..9d24035 100644
--- a/common/modules/mango/default.nix
+++ b/common/modules/window_managers/mango/default.nix
@@ -11,7 +11,7 @@
...
}:
let
- cfg = config.${moduleNameSpace}.mango;
+ cfg = config.${moduleNameSpace}.windowManagers;
snip = pkgs.writeShellScript "snip" ''
case $1 in
full)
@@ -50,37 +50,7 @@ in
imports =
if homeManager then [ inputs.mango.hmModules.mango ] else [ inputs.mango.nixosModules.mango ];
- options.${moduleNameSpace}.mango = {
- enable = lib.mkEnableOption "mango setup";
- animations = lib.mkEnableOption "Uiiiiiiiiiii";
- waybar = lib.mkEnableOption "Enable waybar";
- window = {
- blur = {
- enable = lib.mkEnableOption "Enable window blur";
- passes = lib.mkOption {
- type = lib.types.int;
- default = 1;
- };
- radius = lib.mkOption {
- type = lib.types.int;
- default = 10;
- };
- };
- shadows = lib.mkEnableOption "Enable window drop shadows";
- border_radius = lib.mkOption {
- type = lib.types.int;
- default = 0;
- description = "Border radius";
- };
- opacity = lib.mkOption {
- type = lib.types.number;
- default = 1.0;
- description = "Window opacity";
- };
- };
- };
-
- config = lib.mkIf cfg.enable (
+ config = lib.mkIf cfg.mango.enable (
if homeManager then
{
wayland.windowManager.mango = {
@@ -93,17 +63,17 @@ in
''}
# Window effect
- blur=${if cfg.window.blur.enable then "1" else "0"}
+ blur=${if cfg.eyeCandy.window.blur.enable then "1" else "0"}
blur_layer=0
blur_optimized=1
- blur_params_num_passes = ${toString cfg.window.blur.passes}
- blur_params_radius = ${toString cfg.window.blur.radius}
+ blur_params_num_passes = ${toString cfg.eyeCandy.window.blur.passes}
+ blur_params_radius = ${toString cfg.eyeCandy.window.blur.radius}
blur_params_noise = 0.02
blur_params_brightness = 0.9
blur_params_contrast = 0.9
blur_params_saturation = 1.2
- shadows=${if cfg.window.shadows then "1" else "0"}
+ shadows=${if cfg.eyeCandy.window.shadows.enable then "1" else "0"}
layer_shadows = 0
shadow_only_floating = 1
shadows_size = 10
@@ -111,25 +81,25 @@ in
shadows_position_x = 0
shadows_position_y = 0
- border_radius=${toString cfg.window.border_radius}
+ border_radius=${toString cfg.eyeCandy.window.borderRadius}
no_radius_when_single=0
${
- if (cfg.window.blur.enable && cfg.window.opacity == 1.0) then
+ if (cfg.eyeCandy.window.blur.enable && cfg.eyeCandy.window.opacity == 1.0) then
''
focused_opacity=0.82
unfocused_opacity=0.82
''
else
''
- focused_opacity=${toString cfg.window.opacity}
- unfocused_opacity=${toString cfg.window.opacity}
+ focused_opacity=${toString cfg.eyeCandy.window.opacity}
+ unfocused_opacity=${toString cfg.eyeCandy.window.opacity}
''
}
# Animation Configuration(support type:zoom,slide)
# tag_animation_direction: 1-horizontal,0-vertical
- animations=${if cfg.animations then "1" else "0"}
+ animations=${if cfg.eyeCandy.animations.enable then "1" else "0"}
layer_animations=0
animation_type_open=slide
animation_type_close=zoom
@@ -390,23 +360,14 @@ in
wl-paste --type text --watch cliphist store &
gnome-keyring-daemon --start --components=secrets,ssh,pkcs11 &
- ${lib.optionalString (config.beeMods.dwm.enable) ''
+ ${lib.optionalString (config.beeMods.windowManagers.dwm.enable) ''
systemctl --user stop xidlehook.service
systemctl --user stop xautolock-session.service
systemctl --user stop xss-lock.service
systemctl --user stop clipcat.service
''}
-
- ${lib.optionalString (config.beeMods.dwm.picom.enable) ''
- systemctl --user stop picom.service
- ''}
'';
};
- home.packages = with pkgs; [
- wl-clipboard
- cliphist
- brightnessctl
- ];
}
else
{
diff --git a/common/programs/vesktop.nix b/common/programs/vesktop.nix
deleted file mode 100644
index 41a9e56..0000000
--- a/common/programs/vesktop.nix
+++ /dev/null
@@ -1,29 +0,0 @@
-{ lib, config, ... }:
-{
- programs.vesktop = {
- enable = true;
- vencord = {
- settings = {
- enabledThemes = lib.optionals config.beeMods.matugen.enable [ "system24.css" ];
- autoUpdate = false;
- autoUpdateNotification = false;
- notifyAboutUpdates = false;
- useQuickCss = false;
- disableMinSize = true;
- plugins = {
- FakeNitro.enabled = false;
- AnonymiseFileNames.enabled = true;
- PlainFolderIcon.enabled = true;
- NoTypingAnimation.enabled = true;
- NoF1.enabled = true;
- petpet.enabled = true;
- QuickReply.enabled = true;
- SilentTyping.enabled = true;
- StreamerModeOnStream.enabled = false;
- NoReplyMention.enabled = true;
- OnePingPerDM.enabled = false;
- };
- };
- };
- };
-}
diff --git a/common/modules/hyprland/default.nix b/common/modules/window_managers/hyprland/default.nix
index d230ac0..c338f44 100644
--- a/common/modules/hyprland/default.nix
+++ b/common/modules/window_managers/hyprland/default.nix
@@ -11,7 +11,7 @@
...
}:
let
- cfg = config.${moduleNameSpace}.hyprland;
+ cfg = config.${moduleNameSpace}.windowManagers;
snip = pkgs.writeShellScript "snip" ''
case $1 in
@@ -44,50 +44,9 @@ let
smart-ghostty
else
config.beeMods.terminal.default;
-
- settings-persist = pkgs.writeShellScript "settings-persist" ''
- SETTINGS_FILE="$HOME/.config/beeSettings"
-
- if [[ -f "$SETTINGS_FILE" ]]; then
- IS_NIGHTMODE=$(${pkgs.ripgrep}/bin/rg "nightlight" "$SETTINGS_FILE" | cut -d"=" -f2)
-
- if [[ "$IS_NIGHTMODE" == "on" ]]; then
- ${pkgs.wlsunset}/bin/wlsunset -T 4500 &
- fi
- fi
- '';
in
{
- options.${moduleNameSpace}.hyprland = {
- enable = lib.mkEnableOption "hyprland setup";
- animations = lib.mkEnableOption "Uiiiiiiiiiii";
- window = {
- blur = {
- enable = lib.mkEnableOption "Enable window blur";
- passes = lib.mkOption {
- type = lib.types.int;
- default = 1;
- };
- radius = lib.mkOption {
- type = lib.types.int;
- default = 10;
- };
- };
- shadows = lib.mkEnableOption "Enable window drop shadows";
- border_radius = lib.mkOption {
- type = lib.types.int;
- default = 0;
- description = "Border radius";
- };
- opacity = lib.mkOption {
- type = lib.types.number;
- default = 1.0;
- description = "Window opacity";
- };
- };
- };
-
- config = lib.mkIf cfg.enable (
+ config = lib.mkIf cfg.hyprland.enable (
if homeManager then
{
wayland.windowManager.hyprland = {
@@ -100,8 +59,7 @@ in
settings = {
monitor = [ ",1920x1080@120,auto,1.0" ];
- # Conditionally load matugen colors if enabled
- # source = [ ] ++ lib.optional (config.beeMods.matugen.enable) "~/.config/hypr/hyprland-colors.conf";
+ source = [ ] ++ lib.optional (config.beeMods.matugen.enable) "~/.config/hypr/dms/colors.conf";
"$mainMod" = "SUPER";
@@ -114,24 +72,17 @@ in
# "GDK_BACKEND,wayland,x11"
# "GDK_SCALE,1"
# ];
- #
+
exec-once = [
- "wl-clip-persist --clipboard regular --reconnect-tries 0"
- "wl-paste --type text --watch cliphist store"
- "${pkgs.polkit_gnome}/libexec/polkit-gnome-authentication-agent-1"
- "gnome-keyring-daemon --start --components=secrets,ssh,pkcs11"
- "${settings-persist}"
"dbus-update-activation-environment --all"
"sleep 1 && dbus-update-activation-environment --systemd WAYLAND_DISPLAY XDG_CURRENT_DESKTOP"
+ "gnome-keyring-daemon --start --components=secrets,ssh,pkcs11"
]
- ++ lib.optionals (config.beeMods.x11.dwm.enable || config.beeMods.x11.bspwm.enable) [
+ ++ lib.optionals config.beeMods.windowManagers.dwm.enable [
"systemctl --user stop xidlehook.service"
"systemctl --user stop xautolock-session.service"
"systemctl --user stop xss-lock.service"
"systemctl --user stop clipcat.service"
- ]
- ++ lib.optionals (config.beeMods.x11.picom.enable) [
- "systemctl --user stop picom.service"
];
xwayland = {
@@ -158,8 +109,8 @@ in
general = {
layout = "master";
- gaps_in = 5;
- gaps_out = 5;
+ gaps_in = 4;
+ gaps_out = 4;
border_size = 2;
resize_on_border = true;
@@ -182,12 +133,12 @@ in
};
decoration = {
- rounding = cfg.window.border_radius;
+ rounding = cfg.eyeCandy.window.borderRadius;
blur = {
- enabled = cfg.window.blur.enable;
- size = cfg.window.blur.radius;
- passes = cfg.window.blur.passes;
+ enabled = cfg.eyeCandy.window.blur.enable;
+ size = cfg.eyeCandy.window.blur.radius;
+ passes = cfg.eyeCandy.window.blur.passes;
brightness = 0.9;
contrast = 0.9;
noise = 0.02;
@@ -197,7 +148,7 @@ in
};
shadow = {
- enabled = cfg.window.shadows;
+ enabled = cfg.eyeCandy.window.shadows.enable;
ignore_window = true;
range = 10;
render_power = 3;
@@ -205,18 +156,24 @@ in
color = "rgba(00000044)";
};
# Apply opacity logic utilizing cfg options
active_opacity =
- if (cfg.window.blur.enable && cfg.window.opacity == 1.0) then 0.82 else cfg.window.opacity;
+ if (cfg.eyeCandy.window.blur.enable && cfg.eyeCandy.window.opacity == 1.0) then
+ 0.82
+ else
+ cfg.eyeCandy.window.opacity;
inactive_opacity =
- if (cfg.window.blur.enable && cfg.window.opacity == 1.0) then 0.82 else cfg.window.opacity;
+ if (cfg.eyeCandy.window.blur.enable && cfg.eyeCandy.window.opacity == 1.0) then
+ 0.82
+ else
+ cfg.eyeCandy.window.opacity;
fullscreen_opacity = 1.0;
dim_inactive = false;
};
animations = {
- enabled = true;
+ enabled = cfg.eyeCandy.animations.enable;
bezier = [
"openCurve, 0.05, 0.7, 0.1, 1.0"
@@ -265,6 +222,8 @@ in
layerrule = [
"no_anim on, match:namespace ^rofi$"
+ "no_anim on, match:namespace ^(dms)$"
+ "no_anim on, match:namespace .*dms.*"
];
workspace = [ "2, layout:scrolling" ];
@@ -272,11 +231,12 @@ in
bind = [
"$mainMod, r, exec, hyprctl reload"
"$mainMod, Return, exec, ${terminal}"
- "$mainMod, a, exec, rofi -show drun"
- "$mainMod, period, exec, rofi -show emoji -modi emoji"
- "ALT, F4, exec, rofi -show power-menu -modi power-menu:rofi-power-menu"
- "$mainMod, y, exec, beesettings wall"
- "$mainMod, comma, exec, beesettings settings"
+ "$mainMod, a, exec,dms ipc call spotlight toggle"
+ "$mainMod, v,exec,dms ipc call clipboard toggle"
+ "ALT, F4, exec, dms ipc call powermenu toggle"
+ "$mainMod, y, exec, dms ipc call dankdash wallpaper"
+
+ "$mainMod, comma, exec,dms ipc call settings focusOrToggle"
"$mainMod, F12, exec, gnome-calculator"
"$mainMod, b, exec, zen"
@@ -351,18 +311,18 @@ in
];
bindel = [
- ", XF86AudioRaiseVolume, exec, volume-control up"
- ", XF86AudioLowerVolume, exec, volume-control down"
- ", XF86AudioMute, exec, volume-control mute"
- ", XF86AudioMicMute, exec, mic-control toggle"
+ ", XF86AudioRaiseVolume, exec, wpctl set-volume -l 1.5 @DEFAULT_AUDIO_SINK@ 5%+"
+ ", XF86AudioLowerVolume, exec, wpctl set-volume @DEFAULT_AUDIO_SINK@ 5%-"
+ ", XF86AudioMute, exec,wpctl set-mute @DEFAULT_AUDIO_SINK@ toggle"
+ ", XF86AudioMicMute, exec,wpctl set-mute @DEFAULT_AUDIO_SOURCE@ toggle"
", XF86AudioPlay, exec, playerctl play-pause"
", XF86AudioNext, exec, playerctl next"
", XF86AudioPrev, exec, playerctl previous"
", XF86AudioStop, exec, playerctl stop"
- ", XF86MonBrightnessUp, exec, brightness-control up"
- ", XF86MonBrightnessDown, exec, brightness-control down"
+ ", XF86MonBrightnessUp, exec,brightnessctl set +5%"
+ ", XF86MonBrightnessDown, exec, brightnessctl set 5%-"
];
bindm = [
@@ -374,7 +334,10 @@ in
}
else
{
- programs.hyprland.enable = true;
+ programs.hyprland = {
+ enable = true;
+ withUWSM = false;
+ };
}
);
}
@@ -205,18 +156,24 @@ in
color = "rgba(00000044)";
};
- # Apply opacity logic utilizing cfg options
+ # Apply opacity logic utilizing cfg.eyeCandy.options
active_opacity =